@@ -1,33 +1,20 @@
 /*
-    Copyright 2010-2012 Lamarque Souza <lamarque@kde.org>
+    SPDX-FileCopyrightText: 2010-2012 Lamarque Souza <lamarque@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#include "debug.h"
 #include "mobileproviders.h"
+#include "debug.h"
 
 #include <QFile>
-#include <QTextStream>
 #include <QLocale>
+#include <QTextStream>
 
-const QString MobileProviders::ProvidersFile = "/usr/share/mobile-broadband-provider-info/serviceproviders.xml";
+const QString MobileProviders::ProvidersFile = QStringLiteral(BROADBANDPROVIDER_DATABASE);
 
-bool localeAwareCompare(const QString & one, const QString & two) {
+bool localeAwareCompare(const QString &one, const QString &two)
+{
     return one.localeAwareCompare(two) < 0;
 }
 
@@ -66,7 +53,8 @@ MobileProviders::MobileProviders()
                     mError = ProvidersWrongFormat;
                 } else {
                     if (docElement.attribute("format") != "2.0") {
-                        qCWarning(PLASMA_NM) << ProvidersFile << ": mobile broadband provider database format '" << docElement.attribute("format") << "' not supported.";
+                        qCWarning(PLASMA_NM) << ProvidersFile << ": mobile broadband provider database format '" << docElement.attribute("format")
+                                             << "' not supported.";
                         mError = ProvidersFormatNotSupported;
                     } else {
                         // qCDebug(PLASMA_NM) << "Everything is alright so far";
@@ -140,10 +128,10 @@ QStringList MobileProviders::getProvidersList(QString country, NetworkManager::C
                             } else if (e3.tagName().toLower() == "name") {
                                 QString lang = e3.attribute("xml:lang");
                                 if (lang.isEmpty()) {
-                                    lang = "en";     // English is default
+                                    lang = "en"; // English is default
                                 } else {
                                     lang = lang.toLower();
-                                    lang.remove(QRegExp("\\-.*$"));  // Remove everything after '-' in xml:lang attribute.
+                                    lang.remove(QRegExp("\\-.*$")); // Remove everything after '-' in xml:lang attribute.
                                 }
                                 localizedProviderNames.insert(lang, e3.text());
                             }
@@ -173,7 +161,7 @@ QStringList MobileProviders::getProvidersList(QString country, NetworkManager::C
     return sortedCdma.values();
 }
 
-QStringList MobileProviders::getApns(const QString & provider)
+QStringList MobileProviders::getApns(const QString &provider)
 {
     mApns.clear();
     mNetworkIds.clear();
@@ -196,10 +184,8 @@ QStringList MobileProviders::getApns(const QString & provider)
                     QDomNode n3 = e2.firstChild();
                     while (!n3.isNull()) {
                         QDomElement e3 = n3.toElement(); // <usage>
-                        if (!e3.isNull() &&
-                            e3.tagName().toLower() == "usage" &&
-                            !e3.attribute("type").isNull() &&
-                            e3.attribute("type").toLower() != "internet") {
+                        if (!e3.isNull() && e3.tagName().toLower() == "usage" && !e3.attribute("type").isNull()
+                            && e3.attribute("type").toLower() != "internet") {
                             // qCDebug(PLASMA_NM) << "apn" << e2.attribute("value") << "ignored because of usage" << e3.attribute("type");
                             isInternet = false;
                             break;
@@ -224,8 +210,77 @@ QStringList MobileProviders::getApns(const QString & provider)
     return temp;
 }
 
+ProviderData MobileProviders::parseProvider(const QDomNode &providerNode)
+{
+    ProviderData result;
 
-QStringList MobileProviders::getNetworkIds(const QString & provider)
+    QMap<QString, QString> localizedProviderNames;
+
+    QDomNode c = providerNode.firstChild(); // <name | gsm | cdma>
+
+    while (!c.isNull()) {
+        QDomElement ce = c.toElement();
+
+        if (ce.tagName().toLower() == QLatin1String("gsm")) {
+            QDomNode gsmNode = c.firstChild();
+
+            while (!gsmNode.isNull()) {
+                QDomElement gsmElement = gsmNode.toElement();
+
+                if (gsmElement.tagName().toLower() == QLatin1String("network-id")) {
+                    result.mccmncs.append(gsmElement.attribute("mcc") + gsmElement.attribute("mnc"));
+                }
+                gsmNode = gsmNode.nextSibling();
+            }
+        } else if (ce.tagName().toLower() == QLatin1String("name")) {
+            QString lang = ce.attribute("xml:lang");
+            if (lang.isEmpty()) {
+                lang = "en"; // English is default
+            } else {
+                lang = lang.toLower();
+                lang.remove(QRegExp("\\-.*$")); // Remove everything after '-' in xml:lang attribute.
+            }
+            localizedProviderNames.insert(lang, ce.text());
+        }
+        c = c.nextSibling();
+    }
+
+    result.name = getNameByLocale(localizedProviderNames);
+
+    return result;
+}
+
+QStringList MobileProviders::getProvidersFromMCCMNC(const QString &targetMccMnc)
+{
+    QStringList result;
+
+    QDomNode n = docElement.firstChild();
+
+    while (!n.isNull()) {
+        QDomElement e = n.toElement(); // <country ...>
+
+        if (!e.isNull()) {
+            QDomNode n2 = e.firstChild();
+            while (!n2.isNull()) {
+                QDomElement e2 = n2.toElement(); // <provider ...>
+
+                if (!e2.isNull() && e2.tagName().toLower() == "provider") {
+                    ProviderData data = parseProvider(e2);
+
+                    if (data.mccmncs.contains(targetMccMnc)) {
+                        result << data.name;
+                    }
+                }
+                n2 = n2.nextSibling();
+            }
+        }
+        n = n.nextSibling();
+    }
+
+    return result;
+}
+
+QStringList MobileProviders::getNetworkIds(const QString &provider)
 {
     if (mNetworkIds.isEmpty()) {
         getApns(provider);
@@ -233,7 +288,7 @@ QStringList MobileProviders::getNetworkIds(const QString & provider)
     return mNetworkIds;
 }
 
-QVariantMap MobileProviders::getApnInfo(const QString & apn)
+QVariantMap MobileProviders::getApnInfo(const QString &apn)
 {
     QVariantMap temp;
     QDomNode n = mApns[apn];
@@ -247,10 +302,10 @@ QVariantMap MobileProviders::getApnInfo(const QString & apn)
             if (e.tagName().toLower() == "name") {
                 QString lang = e.attribute("xml:lang");
                 if (lang.isEmpty()) {
-                    lang = "en";     // English is default
+                    lang = "en"; // English is default
                 } else {
                     lang = lang.toLower();
-                    lang.remove(QRegExp("\\-.*$"));  // Remove everything after '-' in xml:lang attribute.
+                    lang.remove(QRegExp("\\-.*$")); // Remove everything after '-' in xml:lang attribute.
                 }
                 localizedPlanNames.insert(lang, e.text());
             } else if (e.tagName().toLower() == "username") {
@@ -276,7 +331,7 @@ QVariantMap MobileProviders::getApnInfo(const QString & apn)
     return temp;
 }
 
-QVariantMap MobileProviders::getCdmaInfo(const QString & provider)
+QVariantMap MobileProviders::getCdmaInfo(const QString &provider)
 {
     if (!mProvidersCdma.contains(provider)) {
         return QVariantMap();
