@@ -1,21 +1,7 @@
 /*
-Copyright 2009 Paul Marchouk <pmarchouk@gmail.com>
+    SPDX-FileCopyrightText: 2009 Paul Marchouk <pmarchouk@gmail.com>
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of
-the License or (at your option) version 3 or any later version
-accepted by the membership of KDE e.V. (or its successor approved
-by the membership of KDE e.V.), which shall act as a proxy
-defined in Section 14 of version 3 of the license.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "simpleipv4addressvalidator.h"
@@ -28,15 +14,15 @@ SimpleIpV4AddressValidator::SimpleIpV4AddressValidator(AddressStyle style, QObje
     , m_addressStyle(style)
 {
     switch (style) {
-        case Base:
-            m_validator.setRegularExpression(QRegularExpression(QLatin1String("[0-9, ]{1,3}\\.[0-9, ]{1,3}\\.[0-9, ]{1,3}\\.[0-9, ]{1,3}")));
-            break;
-        case WithCidr:
-            m_validator.setRegularExpression(QRegularExpression(QLatin1String("([0-9]{1,3}\\.){3,3}[0-9]{1,3}/[0-9]{1,2}")));
-            break;
-        case WithPort:
-            m_validator.setRegularExpression(QRegularExpression(QLatin1String("([0-9]{1,3}\\.){3,3}[0-9]{1,3}:[0-9]{1,5}")));
-            break;
+    case Base:
+        m_validator.setRegularExpression(QRegularExpression(QLatin1String("[0-9, ]{1,3}\\.[0-9, ]{1,3}\\.[0-9, ]{1,3}\\.[0-9, ]{1,3}")));
+        break;
+    case WithCidr:
+        m_validator.setRegularExpression(QRegularExpression(QLatin1String("([0-9]{1,3}\\.){3,3}[0-9]{1,3}/[0-9]{1,2}")));
+        break;
+    case WithPort:
+        m_validator.setRegularExpression(QRegularExpression(QLatin1String("([0-9]{1,3}\\.){3,3}[0-9]{1,3}:[0-9]{1,5}")));
+        break;
     }
 }
 
@@ -127,8 +113,7 @@ QValidator::State SimpleIpV4AddressValidator::checkTetradsRanges(QString &value,
         // not all tetrads are filled... continue
         // qCDebug(PLASMA_NM) << "QValidator::Intermediate";
         return QValidator::Intermediate;
-    }
-    else {
+    } else {
         if (m_addressStyle == WithCidr) {
             if (cidrParts.size() > 1) {
                 value += QLatin1String("/");
@@ -140,8 +125,7 @@ QValidator::State SimpleIpV4AddressValidator::checkTetradsRanges(QString &value,
                         value += cidrParts[1];
                         return QValidator::Acceptable;
                     }
-                }
-                else {
+                } else {
                     return QValidator::Intermediate;
                 }
             }
@@ -156,8 +140,7 @@ QValidator::State SimpleIpV4AddressValidator::checkTetradsRanges(QString &value,
                         value += portParts[1];
                         return QValidator::Acceptable;
                     }
-                }
-                else {
+                } else {
                     return QValidator::Intermediate;
                 }
             }
